@@ -1,18 +1,18 @@
-/* $Id: treeview_private.cc 616 2006-05-11 11:40:25Z murrayc $ */
+/* $Id$ */
 
 /* Copyright(C) 2001-2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or(at your option) any later version.
+ * version 2.1 of the License, or(at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -30,6 +30,9 @@ namespace TreeView_Private
 void SignalProxy_CellData_gtk_callback(GtkTreeViewColumn*, GtkCellRenderer* cell,
                                         GtkTreeModel* model, GtkTreeIter* iter, void* data)
 {
+  if(!model)
+    g_warning("SignalProxy_CellData_gtk_callback(): model is NULL, which is unusual.\n");
+
   TreeViewColumn::SlotCellData* the_slot = static_cast<TreeViewColumn::SlotCellData*>(data);
 
   #ifdef GLIBMM_EXCEPTIONS_ENABLED
@@ -37,7 +40,14 @@ void SignalProxy_CellData_gtk_callback(GtkTreeViewColumn*, GtkCellRenderer* cell
   {
   #endif //GLIBMM_EXCEPTIONS_ENABLE
     // use Slot::operator()
-    (*the_slot)(Glib::wrap(cell, false), TreeIter(model, iter));
+    Gtk::TreeModel::iterator cppiter = TreeIter(model, iter);
+    if(!cppiter->get_model_gobject())
+    {
+      g_warning("SignalProxy_CellData_gtk_callback() The cppiter has no model\n");
+      return; 
+    }
+
+    (*the_slot)(Glib::wrap(cell, false), cppiter);
   #ifdef GLIBMM_EXCEPTIONS_ENABLED
   }
   catch(...)
